@@ -1,8 +1,7 @@
-package Redis::Fast;
+package Redis::Fast 0.37;
 
 BEGIN {
     use XSLoader;
-    our $VERSION = '0.34';
     XSLoader::load __PACKAGE__, $VERSION;
 }
 
@@ -13,10 +12,10 @@ use Carp qw/confess/;
 use Encode;
 use Try::Tiny;
 use Scalar::Util qw(weaken);
+use constant SSL_AVAILABLE => eval { require IO::Socket::SSL };
 
 use Redis::Fast::Sentinel;
 
-
 # small utilities for handling host and port
 sub _join_host_port {
     my ($host, $port) = @_;
@@ -171,7 +170,9 @@ sub new {
           or croak("'sentinels' param must be an ArrayRef");
       defined($self->__get_data->{service} = $args{service})
           or croak("Need 'service' name when using 'sentinels'!");
+      croak("Does not support SSL and sentinels") if exists $args{ssl} and $args{ssl};
       $self->__get_data->{sentinels} = $sentinels;
+      $self->__get_data->{sentinels_password} = $args{sentinels_password};
       my $on_build_sock = sub {
           my $data = $self->__get_data;
           my $sentinels = $data->{sentinels};
@@ -182,6 +183,7 @@ sub new {
               my $sentinel = eval {
                   Redis::Fast::Sentinel->new(
                       server => $sentinel_address,
+                      password      => $data->{sentinels_password},
                       cnx_timeout   => (   exists $data->{sentinels_cnx_timeout}
                                                ? $data->{sentinels_cnx_timeout}   : 0.1),
                       read_timeout  => (   exists $data->{sentinels_read_timeout}
@@ -238,6 +240,14 @@ sub new {
   $self->__set_cnx_timeout($args{cnx_timeout} || -1);
   $self->__set_read_timeout($args{read_timeout} || -1);
   $self->__set_write_timeout($args{write_timeout} || -1);
+  $self->__set_ssl($args{ssl} || 0);
+  if ($args{ssl} && SSL_AVAILABLE && $args{SSL_verify_mode}) {
+    # To pass the SSL verify mode to the underlying bindings, we'll use a string
+    $self->__set_ssl_verify_mode("SSL_VERIFY_NONE") if ($args{SSL_verify_mode} == IO::Socket::SSL::SSL_VERIFY_NONE);
+    $self->__set_ssl_verify_mode("SSL_VERIFY_PEER") if ($args{SSL_verify_mode} == IO::Socket::SSL::SSL_VERIFY_PEER);
+    $self->__set_ssl_verify_mode("SSL_VERIFY_FAIL_IF_NO_PEER_CERT") if ($args{SSL_verify_mode} == IO::Socket::SSL::SSL_VERIFY_FAIL_IF_NO_PEER_CERT);
+    $self->__set_ssl_verify_mode("SSL_VERIFY_CLIENT_ONCE") if ($args{SSL_verify_mode} == IO::Socket::SSL::SSL_VERIFY_CLIENT_ONCE);
+  }
 
   if (my $cb = $self->_new_reconnect_on_error_cb($args{reconnect_on_error})) {
       $self->__set_reconnect_on_error($cb);
@@ -487,6 +497,13 @@ Redis::Fast - Perl binding for Redis database
       name => sub { "cache-$$-".++$generation },
     );
 
+    ## Use Sentinels, possibly with password
+    my $redis = Redis::Fast->new(
+      sentinels => [ '10.0.0.1:16379', '10.0.0.2:16379', ],
+      service   => 'mymaster',
+      sentinels_password => 'TheB1gS3CR3T', # optional
+    );
+
     ## Use UNIX domain socket
     my $redis = Redis::Fast->new(sock => '/path/to/socket');
 
